==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/model/TrendPointResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for TrendPoint
 */
@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:57+0800"
)
public class TrendPointResponseProjection extends GraphQLResponseProjection {

    public TrendPointResponseProjection() {
    }

    @Override
    public TrendPointResponseProjection all$() {
        return all$(3);
    }

    @Override
    public TrendPointResponseProjection all$(int maxDepth) {
        this.timestamp();
        this.count();
        this.typename();
        return this;
    }

    public TrendPointResponseProjection timestamp() {
        return timestamp(null);
    }

    public TrendPointResponseProjection timestamp(String alias) {
        fields.add(new GraphQLResponseField("timestamp").alias(alias));
        return this;
    }

    public TrendPointResponseProjection count() {
        return count(null);
    }

    public TrendPointResponseProjection count(String alias) {
        fields.add(new GraphQLResponseField("count").alias(alias));
        return this;
    }

    public TrendPointResponseProjection typename() {
        return typename(null);
    }

    public TrendPointResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/model/TrendPointResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for TrendPoint
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
public class TrendPointResponseProjection extends GraphQLResponseProjection {

    public TrendPointResponseProjection() {
    }

    @Override
    public TrendPointResponseProjection all$() {
        return all$(3);
    }

    @Override
    public TrendPointResponseProjection all$(int maxDepth) {
        this.timestamp();
        this.count();
        this.typename();
        return this;
    }

    public TrendPointResponseProjection timestamp() {
        return timestamp(null);
    }

    public TrendPointResponseProjection timestamp(String alias) {
        fields.add(new GraphQLResponseField("timestamp").alias(alias));
        return this;
    }

    public TrendPointResponseProjection count() {
        return count(null);
    }

    public TrendPointResponseProjection count(String alias) {
        fields.add(new GraphQLResponseField("count").alias(alias));
        return this;
    }

    public TrendPointResponseProjection typename() {
        return typename(null);
    }

    public TrendPointResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}
